==> pgbackrest_1.23.orig.tar.gz: pgbackrest-release-1.23/src/config/configRule.c <==
/***********************************************************************************************************************************
Command and Option Rules
***********************************************************************************************************************************/
#include "config.h"
#include "configRule.h"

#include "configRule.auto.c"

/***********************************************************************************************************************************
cfgCommandTotal - total number of commands
***********************************************************************************************************************************/
uint32
cfgCommandTotal()
{
    return CFGCMDDEF_TOTAL;
}

/***********************************************************************************************************************************
cfgOptionTotal - total number of configuration options
***********************************************************************************************************************************/
uint32
cfgOptionTotal()
{
    return CFGOPTDEF_TOTAL;
}

/***********************************************************************************************************************************
cfgRuleOptionAllowListValueValid - check if the value matches a value in the allow list
***********************************************************************************************************************************/
bool
cfgRuleOptionAllowListValueValid(uint32 uiCommandId, uint32 uiOptionId, const char *szValue)
{
    if (szValue != NULL)
    {
        for (uint32 uiIndex = 0; uiIndex < cfgRuleOptionAllowListValueTotal(uiCommandId, uiOptionId); uiIndex++)
            if (strcmp(szValue, cfgRuleOptionAllowListValue(uiCommandId, uiOptionId, uiIndex)) == 0)
                return true;
    }

    return false;
}

/***********************************************************************************************************************************
cfgRuleOptionDependValueValid - check if the value matches a value in the allow list
***********************************************************************************************************************************/
bool
cfgRuleOptionDependValueValid(uint32 uiCommandId, uint32 uiOptionId, const char *szValue)
{
    if (szValue != NULL)
    {
        for (uint32 uiIndex = 0; uiIndex < cfgRuleOptionDependValueTotal(uiCommandId, uiOptionId); uiIndex++)
            if (strcmp(szValue, cfgRuleOptionDependValue(uiCommandId, uiOptionId, uiIndex)) == 0)
                return true;
    }

    return false;
}

==> pgbackrest_1.25.orig.tar.gz: pgbackrest-release-1.25/src/config/configRule.c <==
/***********************************************************************************************************************************
Command and Option Configuration Rules
***********************************************************************************************************************************/
#include <string.h>

#include "config.h"
#include "configRule.h"

#include "configRule.auto.c"

/***********************************************************************************************************************************
cfgCommandTotal - total number of commands
***********************************************************************************************************************************/
int
cfgCommandTotal()
{
    return CFGCMDDEF_TOTAL;
}

/***********************************************************************************************************************************
cfgOptionTotal - total number of configuration options
***********************************************************************************************************************************/
int
cfgOptionTotal()
{
    return CFGOPTDEF_TOTAL;
}

/***********************************************************************************************************************************
cfgRuleOptionAllowListValueValid - check if the value matches a value in the allow list
***********************************************************************************************************************************/
bool
cfgRuleOptionAllowListValueValid(int commandId, int optionId, const char *value)
{
    if (value != NULL)
    {
        for (int valueIdx = 0; valueIdx < cfgRuleOptionAllowListValueTotal(commandId, optionId); valueIdx++)
            if (strcmp(value, cfgRuleOptionAllowListValue(commandId, optionId, valueIdx)) == 0)
                return true;
    }

    return false;
}

/***********************************************************************************************************************************
cfgRuleOptionDependValueValid - check if the value matches a value in the allow list
***********************************************************************************************************************************/
bool
cfgRuleOptionDependValueValid(int commandId, int optionId, const char *value)
{
    if (value != NULL)
    {
        for (int valueIdx = 0; valueIdx < cfgRuleOptionDependValueTotal(commandId, optionId); valueIdx++)
            if (strcmp(value, cfgRuleOptionDependValue(commandId, optionId, valueIdx)) == 0)
                return true;
    }

    return false;
}
